@@ -3,10 +3,12 @@ function(x,type="const",ic="aic",pmax)
 {
 K <- ncol(x)
 icmat <- matrix(NA,nrow=pmax+1)
+m=t(t(x)-colMeans(x))
+
 for(i in 0:pmax)
 {
 T <- nrow(x)-i
-if(i==0) sigu=(t(x-mean(x)) %*% (x-mean(x)))/nrow(x)
+if(i==0) sigu=(t(m) %*% m)/nrow(x)
 if(i > 0) sigu <- VAR.est(x,p=i,type)$sigu *( (T-K*i-1)/(T))
 LL <- log(det(sigu)); n <- i*K^2
 #if(type=="none") n <- i*K^2
